<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="110px">
      <el-form-item label="重要风险点编码" prop="fRiskCode">
        <el-input
          v-model="queryParams.fRiskCode"
          placeholder="请输入重要风险点编码"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="重要风险点名称" prop="fRiskName">
        <el-input
          v-model="queryParams.fRiskName"
          placeholder="请输入重要风险点名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="重要风险点类型" prop="fRiskType">
        <el-select v-model="queryParams.fRiskType" placeholder="请选择重要风险点类型" clearable size="small">
          <el-option
            v-for="dict in fRiskTypeOptions"
            :key="dict.dictValue"
            :label="dict.dictLabel"
            :value="dict.dictValue"
          />
        </el-select>
      </el-form-item>
      
      <el-form-item label="上报状态" prop="entUploadState">
        <el-select v-model="queryParams.entUploadState" placeholder="请选择上报状态" clearable size="small">
          <el-option label="未上报" value="0" />
          <el-option label="已上报" value="1" />
        </el-select>
      </el-form-item>

      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-if="user.roleId==5"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-if="user.roleId==5"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-if="user.roleId==5"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
		      :loading="exportLoading"
          @click="handleExport"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="inforList" @selection-change="handleSelectionChange"> 
      <el-table-column label="重要风险点编码" align="center" prop="fRiskCode" />
      <el-table-column label="重要风险点名称" align="center" prop="fRiskName" :show-overflow-tooltip="true"/>
      <el-table-column label="燃气企业" align="center" prop="fCompanyId"  width="250" :formatter="fCompanyIdFormat"/>
      <el-table-column label="县级行政区" align="center" prop="fRegionId" :formatter="fRegionIdFormat"/>
      <el-table-column label="重要风险点类型" align="center" prop="fRiskType" :formatter="fRiskTypeFormat" :show-overflow-tooltip="true"/>
      <!-- <el-table-column label="备注" align="center" prop="fRemark" :show-overflow-tooltip="true"/> -->
      <el-table-column :label="uploadStateLabel" align="center" prop="fUploadType" :formatter="uploadStateFormat"> 
      </el-table-column>
      <el-table-column :label="uploadTimeLabel" align="center" prop="fUploadTime" width="150" :formatter="uploadTimeFormat"> 
      </el-table-column>

      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-document"
            @click="handleDetail(scope.row)"
          >详情</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-if="user.roleId==5&&scope.row.entUploadState==0"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-if="user.roleId==5&&scope.row.entUploadState==0"
          >删除</el-button>
          <el-button
            size="mini"
            type="text"
            @click="handleReport(scope.row)"
            v-if="judgeUploadIsShow((scope.row))"
          >上报</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改重要风险点管控对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="900px" append-to-body destroy-on-close :close-on-click-modal="false">
      <el-form ref="form" :model="form" :rules="rules" label-width="140px">
        <el-row class="el-row-table">

          <el-col :span="12">
            <el-form-item label="重要风险点名称" prop="fRiskName">
              <el-input v-model="form.fRiskName" placeholder="请输入重要风险点名称" />
            </el-form-item>
          </el-col>

          <el-col :span="12">
            <el-form-item label="燃气企业" prop="fCompanyId"> 
              <el-select style="width: 100%;" :disabled="isDisabledEnterprise" v-model="form.fCompanyId" placeholder="请选择">
                <el-option
                  v-for="item in enterprises"
                  :key="item.enterpriseId"
                  :label="item.enterpriseName"
                  :value="item.enterpriseId">
                </el-option>
              </el-select>

            </el-form-item>
          </el-col>

          <el-col :span="12">
            <el-form-item label="县级行政区" prop="fRegionId"> 
              
              <el-select v-model="form.fRegionId" placeholder="请选择县级行政区" style="width: 100%" >
                <el-option
                  v-for="county in countyInfo"
                  :key="county.fId"
                  :label="county.fName.trim()"
                  :value="county.fId"
                />
              </el-select>
            </el-form-item>
          </el-col>

          <el-col :span="12">
            <el-form-item label="重要风险点类型" prop="fRiskType">
              <el-select style="width:100%" v-model="form.fRiskType" placeholder="请选择重要风险点类型">
                <el-option
                  v-for="dict in fRiskTypeOptions"
                  :key="dict.dictValue"
                  :label="dict.dictLabel"
                  :value="parseInt(dict.dictValue)"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>

          <el-col :span="24">
            <el-form-item label="所在位置地址描述" prop="fRiskPlaceDetail">
              <el-input v-model="form.fRiskPlaceDetail" placeholder="请输入所在位置地址描述" />
            </el-form-item>
          </el-col>

          <el-col :span="24">
            <el-form-item label="经纬度坐标" prop="fLon">
              <el-col :span="9">
                <el-input v-model="form.fLon" placeholder="请输入经度"/>
              </el-col>
              <el-col :span="9" style="margin-left: 13px">
                <el-input v-model="form.fLat" placeholder="请输入纬度"/>
              </el-col>
              <el-col :span="4" style="margin-left: 30px">
                <el-button type="primary" plain @click="MapdialogFun">选择经纬度</el-button>
              </el-col>
            </el-form-item>
          </el-col>

          <el-col :span="24">
            <el-form-item label="风险构成" prop="fRiskStructure">
              <el-input type="textarea" v-model="form.fRiskStructure" placeholder="请输入风险构成" />
            </el-form-item>
          </el-col>

          <el-col :span="24">
            <el-form-item label="风险管控措施" prop="fRiskControlMeasures">
              <el-input type="textarea" v-model="form.fRiskControlMeasures" placeholder="请输入风险管控措施" />
            </el-form-item>
          </el-col>

          <el-col :span="24">
            <el-form-item label="备注" prop="fRemark">
              <el-input v-model="form.fRemark" placeholder="请输入备注" />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <GetPos
      :dialogVisible.sync="dialogTableVisibles"
      device=""
      :devicePos="devicePos"
      @close="dialogcancelFun"
      @getPath="getPath"
    />

    <!-- 详情 -->
    <DetailInfo ref="detail"/>

  </div>
</template>

<script>
import { listInfor, getInfor, delInfor, addInfor, updateInfor, exportInfor, reportRiskInfo,entReportRiskInfo } from "@/api/risk/info";
import GetPos from '@/components/GetPos';
import { enterpriseLists } from "@/api/regulation/info";
import DetailInfo from "./components/DetailInfo";
import{getInfo} from "@/api/login"
import { getDefaultCountyList } from "@/api/area/county";
export default {
  name: "Infor",
  components: {
    GetPos,
    DetailInfo
  },
  data() {
    return {
      uploadStateLabel:"",
      uploadTimeLabel:"",
      // 遮罩层
      loading: true,
      user:{},
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      fRiskCodes: [],
      //燃气企业
      enterprises: [],
      //县级行政区
      countyInfo: [],
      isDisabledEnterprise: false,
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 重要风险点管控表格数据
      inforList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      fRiskTypeOptions: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        fRiskCode: null,
        fRiskName: null,
        fRiskType: null,
        entUploadState:null
      },
      // 表单参数
      form: {
        fUploadType: null,
        fUploadTime: null
      },
      // 表单校验
      rules: {
        fRiskName: [
          { required: true, message: "重要风险点名称不能为空", trigger: "blur" }
        ],
        fCompanyId: [
          { required: true, message: "涉及燃气企业编码不能为空", trigger: "blur" }
        ],
        fRiskPlaceDetail: [
          { required: true, message: "所在位置地址描述不能为空", trigger: "blur" }
        ],
        fLon: [
          { required: true, message: "请选择经纬度", trigger: "blur" }
        ],
        fRiskStructure: [
          { required: true, message: "风险构成不能为空", trigger: "blur" }
        ],
        fRiskControlMeasures: [
          { required: true, message: "风险管控不能为空", trigger: "blur" }
        ],
        fRemark: [
          { required: true, message: "备注不能为空", trigger: "blur" }
        ],
        fUpdateTime: [
          { required: true, message: "最后修改时间不能为空", trigger: "blur" }
        ]
      },
      devicePos: [],
      dialogTableVisibles: false
    };
  },
  created() {
    this.getuserInfo();
    this.getDicts("t_risk_type").then(response => {
      this.fRiskTypeOptions = response.data;
    });
    this.getEnterpriseLists();
    this.getCountyInfo();
  },
  methods: {
    //判断 上报是否需要显示，上报分为企业上报 和 政府端上报
    judgeUploadIsShow(row) { 

      //角色 3 政府角色 5 企业角色
      let roleId = this.user.roleId;

      // 企业端 上报状态 0-未上报，1-已上报
      let entUploadState = row.entUploadState;

      // 政府端 上报状态 0-未上报，1-已上报
      let govUploadState = row.govUploadState;

      // 如果政府端都已经上报，那就不能显示了。
      if(govUploadState === '1') {
        return false;
      }

      // 如果企业端上报了，则企业端就不能显示了，政府端和 超级管理员能显示
      if(entUploadState === '1' && govUploadState === '0') {
        if (roleId === 5) {
          this.uploadStateLabel = "上报状态"
          this.uploadTimeLabel = "上报时间"
          return false;
        } else {
          this.uploadStateLabel = "上报省厅状态"
          this.uploadTimeLabel = "上报省厅时间"
          return true;
        }
      }

      // 别的情况，都显示
      return true;

    },
    //获取县级
    getCountyInfo(){
      getDefaultCountyList().then(res =>{
        if(res.code == 200 && res.data){
        this.countyInfo =  res.data;
      }
    })
    },
    //所属单位
    getEnterpriseLists(){
      const param = {};
        enterpriseLists(param).then(response => {
          this.enterprises = response.rows; 
      });
    },
    getuserInfo(){
      getInfo().then(response => { 
        this.user = response.user.roles[0]
        console.log("response.user.roles[0] = " + response.user.roles[0]);
        this.getList();
      });
    },
    /** 查询重要风险点管控列表 */
    getList() {
      this.loading = true;
      // 企业查自己的数据
      if (this.user.roleId == 5) {
        this.queryParams.fCompanyId = this.$store.state.user.enterpriseId 
      }
      // 政府如果按照状态查的话，是查的 govUploadState
      if (this.user.roleId == 3) {
        this.queryParams.govUploadState = this.queryParams.entUploadState;
      }
      listInfor(this.queryParams).then(response => {
        this.inforList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    
    // 燃气企业
    fCompanyIdFormat(row, column) {  
      let info = this.enterprises.find(item => item.enterpriseId == row.fCompanyId);
      return info?info.enterpriseName:"-";
    },
    
    // 行政区
    fRegionIdFormat(row, column) {  
      let info = this.countyInfo.find(item => item.fId == row.fRegionId);
      return info?info.fName:"-";
    },
    // 重要风险点类型，1 密闭空间，2 人员密集场
    fRiskTypeFormat(row, column) {
      const riskType = this.selectDictLabel(this.fRiskTypeOptions, row.fRiskType);
      return riskType ? riskType : "-";
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        fRiskDevMajInforId: null,
        fRiskCode: null,
        fRiskName: null,
        fCompanyId: null,
        fRegionId: null,
        fRiskType: null,
        fRiskPlaceDetail: null,
        fLon: null,
        fLat: null,
        fRiskStructure: null,
        fRiskControlMeasures: null,
        fRemark: null,
        fUpdateTime: null,
        fUploadType: null,
        fUploadTime: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.fRiskDevMajInforId);
      this.fRiskCodes = selection.map(item => item.fRiskCode);
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加重要风险点管控";
      // 说明是 企业在新增，直接赋值显示就行了。
      if (this.enterprises.length == 1) {
        this.form.fCompanyId = this.enterprises[0].enterpriseId 
        this.isDisabledEnterprise = true;
      }
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const fRiskDevMajInforId = row.fRiskDevMajInforId || this.ids
      getInfor(fRiskDevMajInforId).then(response => {
        this.form = response.data;
        this.open = true;
      // 说明是 企业在新增，直接赋值显示就行了。
      if (this.enterprises.length == 1) {
        this.form.fCompanyId = this.enterprises[0].enterpriseId 
        this.isDisabledEnterprise = true;
      }
        this.title = "修改重要风险点管控";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.fRiskDevMajInforId != null) {
            updateInfor(this.form).then(response => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addInfor(this.form).then(response => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const fRiskDevMajInforIds = row.fRiskDevMajInforId || this.ids;
      const fRiskCodes = row.fRiskCode || this.fRiskCodes;
      this.$confirm('是否确认删除重要风险点管控编号为"' + fRiskCodes + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delInfor(fRiskDevMajInforIds);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有重要风险点管控数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(() => {
          this.exportLoading = true;
          
          // 企业查自己的数据
          if (this.user.roleId == 5) {
            this.queryParams.fCompanyId = this.$store.state.user.enterpriseId 
          }
          // 政府如果按照状态查的话，是查的 govUploadState
          if (this.user.roleId == 3) {
            this.queryParams.govUploadState = this.queryParams.entUploadState;
          }
          return exportInfor(queryParams);
        }).then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        }).catch(() => {});
    },
    /**
     * 经纬度 选择
     * @param res
     */
    getPath(res){
      //确认选择经纬度
      this.form.fLon = res[0];
      this.form.fLat = res[1];
    },
    /**
     * 地图关闭方法
     */
    dialogcancelFun() {
      this.dialogTableVisibles = false;
    },
    /**
     * 经纬度坐标方法
     */
    MapdialogFun() {
      this.dialogTableVisibles = true;
    },
    //详情
    handleDetail(row){
      this.$refs.detail.getDetailInfo(row.fRiskDevMajInforId);
    },
    
    //上报状态动态展示
    uploadStateFormat(row, column) { 
      //角色 1 超级管理员  5 企业
      let roleId = this.user.roleId;
      if (roleId == 5) {
        if (row.entUploadState == '0') {
          return "未上报"
        } else{
          return "已上报"
        } 
      } else { 
        if (row.govUploadState == '0') {
          return "未上报"
        } else{
          return "已上报"
        } 
      } 
    },
    //上报时间动态展示
    uploadTimeFormat(row, column) {
      //角色 1 超级管理员  5 企业
      let roleId = this.user.roleId;
      if (roleId == 5) {
        return row.entUploadTime;
      } else {
        return row.govUploadTime;
      }

    },
    /** 上报按钮操作 */
    handleReport(row) {
      // 如果是 企业，并且 企业端上报状态为0
      if (this.user.roleId == 5 && row.entUploadState == '0') {
        this.$confirm('是否确认上报重要风险点编码为"' + row.fRiskCode + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
          }).then(function() { 
            return entReportRiskInfo({fRiskDevMajInforId : row.fRiskDevMajInforId});
          }).then(() => { 
            this.getList();
            this.msgSuccess("上报成功");
          }).catch(() => {});
      } 
      

      // 如果是  政府，并且 政府端上报状态为0
      if (this.user.roleId == 3  && row.govUploadState == '0') {
        this.$confirm('是否确认上报重要风险点编码为"' + row.fRiskCode + '"的数据项?', "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
        }).then(function() {
          return reportRiskInfo({fRiskDevMajInforId : row.fRiskDevMajInforId});
        }).then(() => {
          this.getList();
          this.msgSuccess("上报成功");
        }).catch(() => {});
      }
    },
  }
};
</script>
